@@ -10,6 +10,7 @@ class HtmlPreviewWidget final : public QLiteHtmlWidget {
     Q_OBJECT
    public:
     HtmlPreviewWidget(QWidget *parent);
+    void setHtml(const QString &text);
 
    Q_SIGNALS:
     void anchorClicked(const QUrl &url);
@@ -22,6 +23,8 @@ class HtmlPreviewWidget final : public QLiteHtmlWidget {
     bool eventFilter(QObject *src, QEvent *e) override;
 
     QNetworkAccessManager m_nam;
+
+    void exportAsHTMLFile();
 };
 
 #endif
